==> ant-design-vue-2.0.0-rc.9.jar: META-INF/resources/webjars/ant-design-vue/2.0.0-rc.9/lib/menu/MenuItem.d.ts <==
import { SiderContextProps } from '../layout/Sider';
declare const _default: import("vue").DefineComponent<{
    attribute: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    };
    rootPrefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    eventKey: import("vue-types").VueTypeDef<import("../_util/type").Key>;
    active: import("vue-types").VueTypeValidableDef<boolean>;
    selectedKeys: import("vue-types").VueTypeValidableDef<unknown[]> & {
        default: () => unknown[];
    };
    disabled: import("vue-types").VueTypeValidableDef<boolean>;
    title: import("vue-types").VueTypeValidableDef<any>;
    index: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    };
    inlineIndent: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    } & {
        default: number;
    };
    level: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    } & {
        default: number;
    };
    mode: import("vue-types").VueTypeDef<string>;
    multiple: import("vue-types").VueTypeValidableDef<boolean>;
    value: import("vue-types").VueTypeValidableDef<any>;
    manualRef: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    } & {
        default: (...args: any[]) => any;
    };
    role: import("vue-types").VueTypeValidableDef<any>;
    subMenuKey: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    itemIcon: import("vue-types").VueTypeValidableDef<any>;
    parentUniKeys: import("vue-types").VueTypeValidableDef<unknown[]> & {
        default: () => unknown[];
    } & {
        default: () => unknown[];
    };
    parentUniKey: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
}, {
    getInlineCollapsed: () => boolean;
    layoutSiderContext: SiderContextProps;
    injectExtraProps: () => {};
}, unknown, {}, {
    onKeyDown(e: HTMLElement): void;
}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    index: number;
    rootPrefixCls: string;
    level: number;
    inlineIndent: number;
    manualRef: (...args: any[]) => any;
    subMenuKey: string;
    parentUniKeys: unknown[];
    parentUniKey: string;
    attribute: {
        [key: string]: any;
    };
    selectedKeys: unknown[];
} & {
    title?: any;
    multiple?: boolean;
    role?: any;
    active?: boolean;
    disabled?: boolean;
    mode?: string;
    value?: any;
    itemIcon?: any;
    eventKey?: import("../_util/type").Key;
}>, {
    index: number;
    rootPrefixCls: string;
    level: number;
    inlineIndent: number;
    manualRef: (...args: any[]) => any;
    subMenuKey: string;
    parentUniKeys: unknown[];
    parentUniKey: string;
    attribute: {
        [key: string]: any;
    };
    selectedKeys: unknown[];
}>;
export default _default;

==> ant-design-vue-2.1.6.jar: META-INF/resources/webjars/ant-design-vue/2.1.6/lib/menu/MenuItem.d.ts <==
import { SiderContextProps } from '../layout/Sider';
declare const _default: import("vue").DefineComponent<{
    onClick: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    attribute: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    };
    rootPrefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    eventKey: import("vue-types").VueTypeDef<string | number>;
    active: import("vue-types").VueTypeValidableDef<boolean>;
    selectedKeys: import("vue-types").VueTypeValidableDef<unknown[]> & {
        default: () => unknown[];
    };
    disabled: import("vue-types").VueTypeValidableDef<boolean>;
    title: import("vue-types").VueTypeValidableDef<any>;
    index: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    };
    inlineIndent: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    } & {
        default: number;
    };
    level: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    } & {
        default: number;
    };
    mode: import("vue-types").VueTypeDef<string>;
    multiple: import("vue-types").VueTypeValidableDef<boolean>;
    value: import("vue-types").VueTypeValidableDef<any>;
    manualRef: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    } & {
        default: (...args: any[]) => any;
    };
    role: import("vue-types").VueTypeValidableDef<any>;
    subMenuKey: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    itemIcon: import("vue-types").VueTypeValidableDef<any>;
    parentUniKeys: import("vue-types").VueTypeValidableDef<unknown[]> & {
        default: () => unknown[];
    } & {
        default: () => unknown[];
    };
    parentUniKey: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
}, {
    getInlineCollapsed: () => boolean;
    layoutSiderContext: SiderContextProps;
    injectExtraProps: () => {};
}, unknown, {}, {
    onKeyDown(e: HTMLElement): void;
}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    onClick: (...args: any[]) => any;
    index: number;
    rootPrefixCls: string;
    level: number;
    inlineIndent: number;
    manualRef: (...args: any[]) => any;
    subMenuKey: string;
    parentUniKeys: unknown[];
    parentUniKey: string;
    attribute: {
        [key: string]: any;
    };
    selectedKeys: unknown[];
} & {
    value?: any;
    title?: any;
    multiple?: boolean;
    role?: any;
    active?: boolean;
    disabled?: boolean;
    mode?: string;
    itemIcon?: any;
    eventKey?: string | number;
}>, {
    onClick: (...args: any[]) => any;
    index: number;
    rootPrefixCls: string;
    level: number;
    inlineIndent: number;
    manualRef: (...args: any[]) => any;
    subMenuKey: string;
    parentUniKeys: unknown[];
    parentUniKey: string;
    attribute: {
        [key: string]: any;
    };
    selectedKeys: unknown[];
}>;
export default _default;
